==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetEndpointRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetEndpointRequest(
    applicationId: __string,
    endpointId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetEndpointRequest = {
    import GetEndpointRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetEndpointRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .endpointId(__string.unwrap(endpointId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetEndpointRequest.ReadOnly =
    zio.aws.pinpoint.model.GetEndpointRequest.wrap(buildAwsValue())
}
object GetEndpointRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetEndpointRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetEndpointRequest =
      zio.aws.pinpoint.model.GetEndpointRequest(applicationId, endpointId)
    def applicationId: __string
    def endpointId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getEndpointId: ZIO[Any, Nothing, __string] = ZIO.succeed(endpointId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetEndpointRequest
  ) extends zio.aws.pinpoint.model.GetEndpointRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val endpointId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.endpointId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetEndpointRequest
  ): zio.aws.pinpoint.model.GetEndpointRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/GetEndpointRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetEndpointRequest(
    applicationId: __string,
    endpointId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetEndpointRequest = {
    import GetEndpointRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetEndpointRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .endpointId(endpointId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetEndpointRequest.ReadOnly =
    zio.aws.pinpoint.model.GetEndpointRequest.wrap(buildAwsValue())
}
object GetEndpointRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetEndpointRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetEndpointRequest =
      zio.aws.pinpoint.model.GetEndpointRequest(applicationId, endpointId)
    def applicationId: __string
    def endpointId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getEndpointId: ZIO[Any, Nothing, __string] = ZIO.succeed(endpointId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetEndpointRequest
  ) extends zio.aws.pinpoint.model.GetEndpointRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val endpointId: __string = impl.endpointId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetEndpointRequest
  ): zio.aws.pinpoint.model.GetEndpointRequest.ReadOnly = new Wrapper(impl)
}
